Kinto-Core
##########

    Kinto-core is the heart of the `Kinto project
    <http://kinto.readthedocs.org/>`_, and also serves as a handy
    toolkit for building Kinto-based backends.

Table of contents
=================

.. toctree::
   :maxdepth: 1

   rationale
   quickstart
   reference/index
   ecosystem
   contributing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
